@@ -93,7 +93,8 @@ static const struct option long_options[] = {
 	{NULL, 0, NULL, 0}
 };
 
-static const char *copyright = "Please report bugs to <netsniff-ng@googlegroups.com>\n"
+static const char *copyright =
+	"Please report bugs at https://github.com/netsniff-ng/netsniff-ng/issues\n"
 	"Copyright (C) 2009-2013 Daniel Borkmann <dborkma@tik.ee.ethz.ch>\n"
 	"Swiss federal institute of technology (ETH Zurich)\n"
 	"Copyright (C) 2013 Tobias Klauser <tklauser@distanz.ch>\n"
@@ -245,7 +246,7 @@ static int stats_proc_net_dev(const char *ifname, struct ifstat *stats)
 		if (strstr(buff, ifname_colon) == NULL)
 			continue;
 
-		if (sscanf(buff, "%*[a-z0-9_ .-]:%llu%llu%llu%llu%llu%llu"
+		if (sscanf(buff, "%*[a-zA-Z0-9_ .-]:%llu%llu%llu%llu%llu%llu"
 			   "%llu%*u%llu%llu%llu%llu%llu%llu%llu",
 			   &stats->rx_bytes, &stats->rx_packets,
 			   &stats->rx_errors, &stats->rx_drops,
