@@ -23,6 +23,19 @@
 #include "mops.h"
 #include "llist.h"
 
+struct cli_def *gcli;
+
+char mz_username[32];
+char mz_password[32];
+char mz_enable[32];
+char mz_listen_addr[16];
+int mz_port;
+struct mops *clipkt; // actual packet used by CLI thread
+
+int clidev;
+
+int cli_debug;
+
 void mz_cli_init(void)
 {
 	amp_head = automops_init();
