@@ -32,9 +32,55 @@
 #include "die.h"
 #include "dev.h"
 
+enum operating_modes mode;
+
+int ipv6_mode;
+int quiet;           // don't even print 'important standard short messages'
+int verbose;         // report character
+int simulate;        // if 1 then don't really send frames
+
+char path[256];
+char filename[256];
+FILE *fp, *fp2;             // global multipurpose file pointer
+
+long double total_d;
+clock_t mz_start, mz_stop;
+
+int mz_rand;
+int bwidth;
+
+int32_t
+  jitter[TIME_COUNT_MAX];
+
+int
+  rtp_log,
+  time0_flag,        // If set then time0 has valid data
+  sqnr0_flag;
+
+u_int8_t
+  mz_ssrc[4];     // holds RTP stream identifier for rcv_rtp()
+
+u_int16_t
+  sqnr_cur,
+  sqnr_last,
+  sqnr_next;
+
+u_int32_t
+  gind,      // a global index to run through deltaRX, deltaTX, and jitter
+  gind_max;  // the amount of entries used in the (ugly oversized) arrays; per default set to TIME_COUNT
+
+struct tx_struct tx;  // NOTE: tx elements are considered as default values for MOPS
+
+struct device_struct device_list[MZ_MAX_DEVICES];
+
+int device_list_entries;
+
 int verbose_level = 0;
 
-static const char *short_options = "46hqvVSxra:A:b:B:c:d:E:f:F:l:p:P:t:T:M:Q:X:";
+char mz_default_config_path[256];
+char mz_default_log_path[256];
+
+static const char *short_options = "46hqvVSxra:A:b:B:c:d:E:f:F:l:p:P:R:t:T:M:Q:X:";
 
 static void signal_handler(int number)
 {
@@ -113,6 +159,7 @@ static void help(void)
 	     "  -l <ip>               Listen address to bind to when in interactive mode, default: 0.0.0.0\n"
 	     "  -4                    IPv4 mode (default)\n"
 	     "  -6                    IPv6 mode\n"
+	     "  -R <PRIO>             Set socket priority\n"
 	     "  -c <count>            Send packet count times, default:1, infinite:0\n"
 	     "  -d <delay>            Apply delay between transmissions. The delay value can be\n"
 	     "                        specified in usec (default, no additional unit needed), or in\n"
@@ -176,7 +223,7 @@ static void version(void)
 	printf("\nmausezahn %s, Git id: %s\n", VERSION_LONG, GITVERSION);
 	puts("a fast versatile traffic generator\n"
 	     "http://www.netsniff-ng.org\n\n"
-	     "Please report bugs to <bugs@netsniff-ng.org>\n"
+	     "Please report bugs at https://github.com/netsniff-ng/netsniff-ng/issues\n"
 	     "Copyright (C) 2008-2010 Herbert Haas <herbert@perihel.at>,\n"
 	     "Copyright (C) 2011 Daniel Borkmann <dborkma@tik.ee.ethz.ch>,\n"
 	     "Swiss federal institute of technology (ETH Zurich)\n"
@@ -191,9 +238,6 @@ int reset(void)
    int i;
    time_t t;
 
-   // Determine platform type sizes:
-   MZ_SIZE_LONG_INT = sizeof(long int);	     
-
    mz_default_config_path[0] = 0x00;
    mz_default_log_path[0] = 0x00;
 
@@ -224,6 +268,7 @@ int reset(void)
    tx.packet_mode = 1;     // assume we don't care about L2
    tx.count = 1;  
    tx.delay = DEFAULT_DELAY;      
+   tx.prio = 0;
    tx.arg_string[0] = '\0';
    
    // Reset Ethernet parameters of TX:
@@ -398,6 +443,7 @@ int getopts (int argc, char *argv[])
 	char hexpld[MAX_PAYLOAD_SIZE*2];
 	int hexpld_specified=0;
 	long delay;
+	long prio;
 	char unit;
 
 	opterr = 1; // let getopt print error message if necessary
@@ -413,6 +459,19 @@ int getopts (int argc, char *argv[])
 			tx.eth_type = 0x86dd;
 			ipv6_mode=1;
 			break;
+		 case 'R':
+			errno = 0;
+			prio = strtol(optarg, NULL, 0);
+			if (errno) {
+				perror("Couldn't parse priority");
+				return -1;
+			}
+			if (prio < 0 || prio > 0xffffffff) {
+				perror("Invalid priority value");
+				return -1;
+			}
+			tx.prio = (int)prio;
+			break;
 		 case 'h':
 			help();
 			break;
@@ -574,8 +633,8 @@ int getopts (int argc, char *argv[])
 			}
 			break;
 		 case '?':
-			if ((optopt == 'a') || (optopt == 'b') || (optopt = 'c') ||
-			    (optopt == 'd') || (optopt == 'f') || (optopt = 'p') ||
+			if ((optopt == 'a') || (optopt == 'b') || (optopt == 'c') ||
+			    (optopt == 'd') || (optopt == 'f') || (optopt == 'p') ||
 			    (optopt == 't') || (optopt == 'm'))
 				fprintf (stderr, " mz/getopts: Option -%c requires an argument.\n", optopt);
 			else if (isprint (optopt))
